@@ -4,15 +4,20 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_07';
+  our $VERSION = '0.17_08';
 
   use Zydeco
     authority => 'cpan:SMONFF',
-    # Only possible since Type::Tiny->version 1.011_009 (unstable) In case of
-    # any problem, all
-    #   has attr ( type => xxx ) attr types
-    # should be quotted. See
-    declare => ['Artwork', 'Collector'],
+    #
+    # Only possible since Type::Tiny->version 1.011_009 (unstable)
+    # declare => ['Artwork', 'Collector'],
+    # When Type::Tiny 1.011 will come out, it will be possible to remove quotes
+    # around the attributes types that are custom Zydeco classes of ours
+    #   has attr ( type => 'xxx' )
+    # See:
+    #   - https://rt.cpan.org/Public/Bug/Display.html?id=133448
+    #   - https://gitlab.com/smonff/art-world/-/issues/37
+    #
     version   => $VERSION;
   use Carp;
   use utf8;
@@ -45,7 +50,7 @@ package Art::World {
   # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     # Should be an object of type Agent
-    has owner  ( type => ArrayRef[ Collector ] );
+    has owner  ( type => 'ArrayRef[ Collector ]' );
     has value  ( is   => rw );
     has status (
       enum            => ['for_sale', 'sold'],
@@ -70,13 +75,18 @@ package Art::World {
       # Dynamic attribute accessor
       my $attribute = $self->isa( 'Art::World::Work' ) ?
         'aura' : 'reputation';
-      if ( $self->$attribute + $gain >= 0 ) {
-        $self->$attribute( $self->$attribute + $gain )
+      if ( $self->can( $attribute )) {
+        if ( $self->$attribute + $gain >= 0 ) {
+          $self->$attribute( $self->$attribute + $gain )
+        } else {
+          carp 'You tried to update ' . $attribute . ' to a value smaller ' .
+            'than zero. Nothing changed.';
+        }
+        return $self->$attribute;
       } else {
-        carp 'You tried to update ' . $attribute . ' to a value smaller ' .
-          'than zero. Nothing changed.';
+        carp 'No such attribute ' . $attribute .
+          ' or we don\'t manage this kind of entity ' . Meta->get_class( $self );
       }
-      return $self->$attribute;
     }
   }
 
@@ -180,7 +190,7 @@ package Art::World {
     class Artist {
 
       has artworks   ( type => ArrayRef );
-      has collectors ( type => ArrayRef[Collector], default => sub { [] } );
+      has collectors ( type => 'ArrayRef[Collector]', default => sub { [] } );
       has collected  ( type => Bool, default => false, is => rw );
       has status (
         enum => [ 'underground', 'homogenic' ],
@@ -214,7 +224,7 @@ package Art::World {
     class Collector with Active, Buyer {
       has money! ( type => Num, is => rw );
       has collection (
-        type    => ArrayRef[Artwork, 0 ],
+        type    => 'ArrayRef[Artwork, 0 ]',
         default => sub { [] },
         is      => rw,
       );
@@ -250,7 +260,7 @@ package Art::World {
     has creation_date;
     has creator(
       is   => ro,
-      # Shoul be an ArrayRef of Agents
+      # TODO Should be an ArrayRef of Agents
       type => ArrayRef[ Object ]
     );
 
@@ -274,7 +284,7 @@ package Art::World {
     class Exhibition extends Event {
       has curator! (
         is   => ro,
-        type => ArrayRef[ Agent ]
+        type => 'ArrayRef[ Agent ]'
       );
     };
   }
